@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 use base qw(Mac::CoreMIDI::Object);
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new_destination {
     my $class = shift;
@@ -47,29 +47,47 @@ __END__
 
 Mac::CoreMIDI::Endpoint - Encapsulates a CoreMIDI Endpoint
 
+=head1 CONSTRUCTORS
+
+=over 4
+
+=item C<my $ep = Mac::CoreMIDI::Endpoint->new_source(name => '...', client => $client)
+
+Creates a new source endpoint for the given client.
+
+=item C<my $ep = Mac::CoreMIDI::Endpoint->new_destination(name => '...', client => $client)
+
+Creates a new destination endpoint for the given client.
+
+=back
+
 =head1 METHODS
 
-=over
+=over 4
 
-=item C<my $ent = $self-E<gt>GetParent()>
+=item C<my $ent = $ep-E<gt>GetParent()>
 
 Returns parent entity for this endpoint.
 
+=item C<$self-E<gt>Read()>
+
+Subclass this function to do processing on read events.
+
 =back
 
 =head1 SEE ALSO
 
-L<Mac::CoreMIDI>
+L<Mac::CoreMIDI>, L<Mac::CoreMIDI::Client>
 
 =head1 AUTHOR
 
-Christian Renz, E<lt>crenz@web42.comE<gt>
+Christian Renz, E<lt>crenz @ web42.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 by Christian Renz
+Copyright 2004-2005 Christian Renz, E<lt>crenz @ web42.comE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
-=cut
+=cut
\ No newline at end of file
